# Float

A real number that conforms to the xsd:float specification

URI: http://www.w3.org/2001/XMLSchema#float

* [base](https://w3id.org/linkml/base): float






## Identifier and Mapping Information


